from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class DeviceActions(object):
    """
    Configuration - Device Actions API
    
    Implements GET POST DEL PUT methods for DeviceActions endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def generateChangePartitionInfo(self, deviceId):
        """
        Get change partition information
        
        Parameters:
        deviceId	 (array):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/changepartition?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def processChangePartition(self, payload):
        """
        Process change partition operation
        
        Parameters:
        payload:	Device change partition request payload
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/changepartition"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response


    def generateDeactivateInfo(self, deviceId):
        """
        Get deactivate partition information
        
        Parameters:
        deviceId	 (array):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/deactivate?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def processDeactivateSmu(self, request):
        """
        Process deactivate operation for smu image
        
        Parameters:
        request:	Device smu image deactivate request
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/deactivate"
        response = self.client.apiCall(HttpMethods.POST, endpoint, request)
        return response


    def processDefaultPartition(self, request):
        """
        Process marking default partition operation
        
        Parameters:
        request:	Marking default partition request
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/defaultpartition"
        response = self.client.apiCall(HttpMethods.POST, endpoint, request)
        return response


    def createFilterVPNList(self):
        """
        Get filter VPN list
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/filter/vpn"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def generateInstallInfo(self, deviceId):
        """
        Generate install info
        
        Parameters:
        deviceId	 (array):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/install?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def processInstall(self, payload):
        """
        Process an installation operation
        
        Parameters:
        payload:	Installation payload
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/install"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response


    def generateDeviceList(self, deviceType, groupId):
        """
        Get list of installed devices
        
        Parameters:
        Parameter Description
		Parameter Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/install/devices/{deviceType}?groupId={groupId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def generateDeviceActionList(self):
        """
        Get device action list
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/list"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def processLxcActivate(self, payload):
        """
        Process an activation operation
        
        Parameters:
        payload:	Activation request payload
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/lxcactivate"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response


    def processLxcDelete(self, payload):
        """
        Process a delete operation
        
        Parameters:
        payload:	Delete request payload
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/lxcdelete"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response


    def processLxcInstall(self, payload):
        """
        Process an installation operation
        
        Parameters:
        payload:	Installation request payload
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/lxcinstall"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response


    def processLxcReload(self, payload):
        """
        Process a reload operation
        
        Parameters:
        payload:	Reload request payload
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/lxcreload"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response


    def processLxcReset(self, payload):
        """
        Process a reset operation
        
        Parameters:
        payload:	Reset request payload
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/lxcreset"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response


    def processLxcUpgrade(self, payload):
        """
        Process an upgrade operation
        
        Parameters:
        payload:	Upgrade request payload
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/lxcupgrade"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response


    def generateRebootInfo(self, deviceId):
        """
        Get device reboot information
        
        Parameters:
        deviceId	 (array):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/reboot?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def processReboot(self, payload):
        """
        Process a reboot operation
        
        Parameters:
        payload:	Device reboot request payload
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/reboot"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response


    def generateRebootDeviceList(self, deviceType, deviceId):
        """
        Get list of rebooted devices
        
        Parameters:
        Parameter Description
		Parameter Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/reboot/devices/{deviceType}?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def generateRediscoverInfo(self):
        """
        Get rediscover operation information
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/rediscover"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def reDiscoverDevices(self, payload):
        """
        Rediscover device
        
        Parameters:
        payload:	Rediscover device request payload
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/rediscover"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response


    def reDiscoverAllDevice(self, payload):
        """
        Rediscover all devices
        
        Parameters:
        payload:	Rediscover device request payload
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/rediscoverall"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response


    def generateRemovePartitionInfo(self, deviceId):
        """
        Get remove partition information
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/removepartition?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def processRemovePartition(self, payload):
        """
        Process remove partition operation
        
        Parameters:
        payload:	Device remove partition request payload
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/removepartition"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response


    def processDeleteAmpApiKey(self, uuid):
        """
        Process amp api key deletion operation
        
        Parameters:
        uuid	 (string):	Uuid
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/security/amp/apikey/{uuid}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response


    def processAmpApiReKey(self, payload):
        """
        Process amp api re-key operation
        
        Parameters:
        ampapire-keyrequestpayload:	AMP API re-key request payload
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/security/amp/rekey"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response


    def testApiKey(self, uuid):
        """
        Get API key from device
        
        Parameters:
        uuid	 (string):	Device uuid
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/security/apikey/{uuid}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def generateSecurityDevicesList(self, policyType, groupId):
        """
        Get list of devices by security policy type
        
        Parameters:
        policyType	 (string):	Policy type
		Parameter Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/security/devices/{policyType}?groupId={groupId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def triggerPendingTasksMonitoring(self):
        """
        Triggers global monitoring thread
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/startmonitor"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def testIoxConfig(self, deviceIP):
        """
        testIoxConfig
        
        Parameters:
        Parameter Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/test/ioxconfig/{deviceIP}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createUniqueVPNList(self, deviceips):
        """
        Create unique VPN list
        
        Parameters:
        deviceips:	Device IPs
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/uniquevpnlist"
        response = self.client.apiCall(HttpMethods.POST, endpoint, deviceips)
        return response


    def processVnfInstall(self, payload):
        """
        Process an installation operation
        
        Parameters:
        payload:	Installation request payload
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/vnfinstall"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response


    def createVPNList(self):
        """
        Create VPN list
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/vpn"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getZTPUpgradeConfig(self):
        """
        Get ZTP upgrade configuration
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/ztp/upgrade"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def processZTPUpgradeConfig(self, ztpConfig):
        """
        Process ZTP upgrade configuration
        
        Parameters:
        ztpConfig:	ZTP upgrade config
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/ztp/upgrade"
        response = self.client.apiCall(HttpMethods.POST, endpoint, ztpConfig)
        return response


    def getZTPUpgradeConfigSetting(self):
        """
        Get ZTP upgrade configuration setting
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/ztp/upgrade/setting"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def processZTPUpgradeConfigSetting(self, ztpSetting):
        """
        Process ZTP upgrade configuration setting
        
        Parameters:
        ztpSetting:	ZTP upgrade setting
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/ztp/upgrade/setting"
        response = self.client.apiCall(HttpMethods.POST, endpoint, ztpSetting)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Stat(object):
    """
    Real-Time Monitoring - Device System Stats API
    
    Implements GET POST DEL PUT methods for DeviceSystemStats endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getStatDataRawData(self, query):
        """
        Get stats raw data
        
        Parameters:
        query	 (string):	Query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/system?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatsRawData(self, query):
        """
        Get stats raw data
        
        Parameters:
        query:	Stats query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/system"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getAggregationDataByQuery(self, query):
        """
        Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
        
        Parameters:
        query	 (string):	Query filter
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/system/aggregation?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getPostAggregationDataByQuery(self, query):
        """
        Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
        
        Parameters:
        query:	Stats query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/system/aggregation"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getPostAggregationAppDataByQuery(self, query):
        """
        Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
        
        Parameters:
        query:	Stats query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/system/app-agg/aggregation"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def createDeviceSystemCPUStat(self, query, deviceId):
        """
        Get device system CPU stats list
        
        Parameters:
        query	 (string):	Query filter
		deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/system/cpu?query={query}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatDataRawDataAsCSV(self, query):
        """
        Get raw data with optional query as CSV
        
        Parameters:
        query	 (string):	Query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/system/csv?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCount(self, query):
        """
        Get response count of a query
        
        Parameters:
        query	 (string):	Query
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/system/doccount?query={query}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCountPost(self, query):
        """
        Get response count of a query
        
        Parameters:
        query:	Query
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/system/doccount"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getStatDataFields(self):
        """
        Get fields and type
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/system/fields"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createDeviceSystemMemoryStat(self, query, deviceId):
        """
        Get device system memory stats list
        
        Parameters:
        query	 (string):	Query filter
		deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/system/memory?query={query}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatBulkRawData(self, query, scrollId, count):
        """
        Get stats raw data
        
        Parameters:
        query	 (string):	Query string
		scrollId	 (string):	ES scroll Id
		count	 (string):	Result size
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/system/page?query={query}&scrollId={scrollId}&count={count}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getPostStatBulkRawData(self, query, scrollId, count):
        """
        Get stats raw data
        
        Parameters:
        query:	Stats query string
		scrollId	 (string):	ES scroll Id
		count	 (string):	Result size
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/system/page?scrollId={scrollId}&count={count}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, query)
        return response


    def getStatQueryFields(self):
        """
        Get query fields
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/system/query/fields"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Vsmart(object):
    """
    Configuration - vSmart Template Policy API
    
    Implements GET POST DEL PUT methods for vSmartTemplatePolicy endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getVSmartPolicyTemplateList(self):
        """
        Get all template vsmart policy list
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/vsmart"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createVSmartTemplate(self, templatepolicy):
        """
        Create template for given policy
        
        Parameters:
        templatepolicy:	Template policy
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/vsmart"
        response = self.client.apiCall(HttpMethods.POST, endpoint, templatepolicy)
        return response


    def activatePolicyForCloudServices(self, templatepolicy, policyId):
        """
        Activate vsmart policy for a given policy id
        
        Parameters:
        templatepolicy:	Template policy
		policyId	 (string):	Policy Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/vsmart/activate/central/{policyId}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, templatepolicy)
        return response


    def activatePolicy(self, templatepolicy, policyId):
        """
        Activate vsmart policy for a given policy id
        
        Parameters:
        templatepolicy:	Template policy
		policyId	 (string):	Policy Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/vsmart/activate/{policyId}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, templatepolicy)
        return response


    def editTemplateWithoutLockChecks(self, templatepolicy, policyId):
        """
        Edit template for given policy id to allow for multiple component edits
        
        Parameters:
        templatepolicy:	Template policy
		policyId	 (string):	Policy Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/vsmart/central/{policyId}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, templatepolicy)
        return response


    def checkVSmartConnectivityStatus(self):
        """
        Check VSmart Connectivity Status
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/vsmart/connectivity/status"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def deActivatePolicy(self, policyId):
        """
        Deactivate vsmart policy for a given policy id
        
        Parameters:
        policyId	 (string):	Policy Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/vsmart/deactivate/{policyId}"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def getTemplateByPolicyId(self, policyId):
        """
        Get template policy definition by policy id
        
        Parameters:
        policyId	 (string):	Policy Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/vsmart/definition/{policyId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def QosmosNbarMigrationWarning(self):
        """
        Qosmos Nbar migration
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/vsmart/qosmos_nbar_migration_warning"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def editVSmartTemplate(self, templatepolicy, policyId):
        """
        Edit template for given policy id
        
        Parameters:
        templatepolicy:	Template policy
		policyId	 (string):	Policy Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/vsmart/{policyId}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, templatepolicy)
        return response


    def deleteVSmartTemplate(self, policyId):
        """
        Delete template for a given policy id
        
        Parameters:
        policyId	 (string):	Policy Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/vsmart/{policyId}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Cluster(object):
    """
    Colocation - Cluster API
    
    Implements GET POST DEL PUT methods for Cluster endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getDetail(self, clusterName):
        """
        Get details of all existing Clusters
        
        Parameters:
        clusterName	 (string):	Cluster name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/cluster?clusterName={clusterName}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def update(self, clusterconfig):
        """
        Update a existing cluster
        
        Parameters:
        clusterconfig:	Cluster config
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/cluster"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, clusterconfig)
        return response


    def create(self, clusterconfig):
        """
        Add a new cluster
        
        Parameters:
        clusterconfig:	Cluster config
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/cluster"
        response = self.client.apiCall(HttpMethods.POST, endpoint, clusterconfig)
        return response


    def acitvate(self, clusterName):
        """
        Activate a cluster
        
        Parameters:
        clusterName	 (string):	Cluster name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/cluster/activate?clusterName={clusterName}"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def dummyccm(self, clusterName):
        """
        Activate dummp cluster
        
        Parameters:
        clusterName	 (string):	Cluster name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/cluster/activateClusterDummy?clusterName={clusterName}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def dummycspState(self, clusterName, state):
        """
        Activate cluster in a state
        
        Parameters:
        clusterName	 (string):	Cluster name
		state	 (string):	Cluster state
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/cluster/activateClusterDummyState?clusterName={clusterName}&state={state}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def updateCspToCluster(self, cspconfig):
        """
        Update attached csp to cluster
        
        Parameters:
        cspconfig:	CSP config
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/cluster/attached/csp"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, cspconfig)
        return response


    def preview(self, serialNumber):
        """
        Clouddock cluster preview
        
        Parameters:
        serialNumber	 (string):	Serial number
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/cluster/config?serialNumber={serialNumber}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def deAcitvate(self, clusterId):
        """
        Deactivate clouddock cluster
        
        Parameters:
        clusterId	 (string):	Cluster Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/cluster/deactivate?clusterId={clusterId}"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def getDetailById(self, clusterId):
        """
        Get cluster by Id
        
        Parameters:
        clusterId	 (string):	Cluster Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/cluster/id?clusterId={clusterId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def rmaCloudDockCsp(self, bodyParameter, clusterName):
        """
        RMA operation for CSP device
        
        Parameters:
        bodyParameter:	Description
		clusterName	 (string):	Cluster name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/cluster/rma?clusterName={clusterName}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, bodyParameter)
        return response


    def deleteByName(self, clustername):
        """
        Delete cluster by name
        
        Parameters:
        clustername	 (string):	Cluster name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/colocation/cluster/{clustername}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class MSLA(object):
    """
    MSLA API
    
    Implements GET POST DEL PUT methods for MSLA endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def editDeviceWithLicense(self, license):
        """
        Update device subscription
        
        Parameters:
        license:	Subscription and license
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/msla/assignLicense"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, license)
        return response


    def createDeviceWithLicense(self, license):
        """
        Create device subscription
        
        Parameters:
        license:	Subscription and license
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/msla/assignLicense"
        response = self.client.apiCall(HttpMethods.POST, endpoint, license)
        return response


    def getMSLADevices(self):
        """
        Retrieve devices subscription
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/msla/devices"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDeviceDistributionOverview(self):
        """
        Get device distribution 
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/msla/devices/assignmentdistribution"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getLicenseandDeviceOverview(self):
        """
        Get license device overview 
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/msla/devices/licenseanddeviceoverviewtable"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getLicenseDistributionOverview(self):
        """
        Get license distribution 
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/msla/devices/licensedistribution"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSubscriptionOverview(self):
        """
        Get subscription overview 
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/msla/devices/subscriptiondistribution"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSubscriptions(self, payload):
        """
        Retrieve MSLA subscription/licenses
        
        Parameters:
        payload:	Request Payload
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/msla/licenses/subscription"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response


    def syncLicenses(self, synclicense):
        """
        Retrieve MSLA subscription/licenses
        
        Parameters:
        synclicense:	Sync license
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/msla/licenses/sync"
        response = self.client.apiCall(HttpMethods.POST, endpoint, synclicense)
        return response


    def getlicensedDeviceCount(self):
        """
        get license and device count
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/msla/monitoring/licensedDeviceCount"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getLicensedDistributionDetails(self):
        """
        get license and device count
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/msla/monitoring/licensedDistributionDetails"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getpackagingDistributionDetails(self):
        """
        get packaging distribution details
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/msla/monitoring/packagingDistributionDetails"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSubscriptions(self):
        """
        Retrieve subscriptions
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/msla/subscriptions"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getAllTemplate(self):
        """
        Retrieve all MSLA template
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/msla/template"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSubscriptions(self, payload):
        """
        Retrieve MSLA subscription/licenses
        
        Parameters:
        payload:	Request Payload
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/msla/template/licenses"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response


    def getSubscriptions(self, payload):
        """
        Retrieve MSLA subscription/licenses
        
        Parameters:
        payload:	Request Payload
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/msla/va/License"
        response = self.client.apiCall(HttpMethods.POST, endpoint, payload)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Rewrite(object):
    """
    Configuration - Policy Rewrite Rule Definition Builder API
    
    Implements GET POST DEL PUT methods for PolicyRewriteRuleDefinitionBuilder endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getDefinitions(self):
        """
        Get policy definitions
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/definition/rewriterule"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def create(self, policydefinition):
        """
        Create policy definition
        
        Parameters:
        policydefinition:	Policy definition
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/definition/rewriterule"
        response = self.client.apiCall(HttpMethods.POST, endpoint, policydefinition)
        return response


    def saveInBulk(self, policydefinition):
        """
        Create/Edit policy definitions in bulk
        
        Parameters:
        policydefinition:	Policy definition
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/definition/rewriterule/bulk"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, policydefinition)
        return response


    def editMultiple(self, policydefinition, id):
        """
        Edit multiple policy definitions
        
        Parameters:
        policydefinition:	Policy definition
		id	 (string):	Policy Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/definition/rewriterule/multiple/{id}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, policydefinition)
        return response


    def preview(self, policydefinition):
        """
        Preview policy definition
        
        Parameters:
        policydefinition:	Policy definition
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/definition/rewriterule/preview"
        response = self.client.apiCall(HttpMethods.POST, endpoint, policydefinition)
        return response


    def previewById(self, id):
        """
        Preview policy definition
        
        Parameters:
        id	 (string):	Policy Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/definition/rewriterule/preview/{id}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def get(self, id):
        """
        Get a specific policy definitions
        
        Parameters:
        id	 (string):	Policy Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/definition/rewriterule/{id}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def edit(self, policydefinition, id):
        """
        Edit a policy definitions
        
        Parameters:
        policydefinition:	Policy definition
		id	 (string):	Policy Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/definition/rewriterule/{id}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, policydefinition)
        return response


    def delete(self, id):
        """
        Delete policy definition
        
        Parameters:
        id	 (string):	Policy Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/template/policy/definition/rewriterule/{id}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response





from py_viptela.response_parser import Parser
import requests

# CONSTANTS
GET = "GET"
POST = "POST"
PUT = "PUT"
DELETE = "DELETE"

class HttpClient(object):
    
    """
    TODO: methods for this class will be implemented last
    """
    def __init__(self, session):
        self.session = session
        self.parser = Parser()

    def apiCall(self, method, url, body=None):
        methods = {
            "GET":self.session.get,
            "POST": self.session.post,
            "PUT": self.session.put,
            "DELETE": self.session.delete
        }
        
        try:
            response = methods[method](url=url, data=body)

        except requests.exceptions.ConnectTimeout:
            return{'error': 'Connection Timeout'}

        except requests.exceptions.ConnectionError:
            return {'error': 'Connection Failed'}

        except requests.exceptions.SSLError:
            return {'error': 'SSL Error'}
            
        except requests.exceptions.Timeout:
            return {'errror': 'Timeout'}
        
        if response.text == '':
            return response.text
        else:
            result_data = Parser.parseResponse(response=response)
            return result_data


from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Processor(object):
    """
    Monitoring - Stats Processing API
    
    Implements GET POST DEL PUT methods for StatsProcessing endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def getStatisticType(self):
        """
        Get statistics types
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def startStatsCollection(self):
        """
        Start stats collect
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/collect"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def generateStatsCollectThreadReport(self):
        """
        Get stats collect thread report
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/collect/thread/status"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def resetStatsCollection(self, processQueue):
        """
        Reset stats collect thread report
        
        Parameters:
        processQueue	 (integer):	Process queue
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/collection/reset/{processQueue}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def enableStatsDemo(self, enable):
        """
        Enable statistic demo mode
        
        Parameters:
        enable	 (boolean):	Demo mode flag
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/demomode?enable={enable}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def processStatsData(self):
        """
        Process stats data
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/process"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatsProcessingCounters(self):
        """
        Get statistics processing counters
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/process/counters"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatsProcessReport(self, processQueue):
        """
        Get stats process report
        
        Parameters:
        processQueue	 (integer):	Process queue
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/process/status?processQueue={processQueue}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatsProcessThreadReport(self):
        """
        Get stats process thread report
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/process/thread/status"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class License(object):
    """
    Smart License API
    
    Implements GET POST DEL PUT methods for SmartLicense endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def sleauthenticate(self, partner):
        """
        authenticate user for sle
        
        Parameters:
        partner:	Partner
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/smartLicensing/authenticate"
        response = self.client.apiCall(HttpMethods.POST, endpoint, partner)
        return response


    def fetchAccounts(self, partner, mode):
        """
        fetch sava for sle
        
        Parameters:
        partner:	Partner
		mode	 (string):	mode
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/smartLicensing/fetchAccounts?mode={mode}"
        response = self.client.apiCall(HttpMethods.GET, endpoint, partner)
        return response


    def fetchReports(self, partner):
        """
        fetch reports offline for sle
        
        Parameters:
        partner:	Partner
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/smartLicensing/fetchAllSa"
        response = self.client.apiCall(HttpMethods.GET, endpoint, partner)
        return response


    def fetchReports(self, partner, saDomain, saId):
        """
        fetch reports offline for sle
        
        Parameters:
        partner:	Partner
		saDomain	 (string):	saDomain
		saId	 (string):	saId
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/smartLicensing/fetchReportsForSa?saDomain={saDomain}&saId={saId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint, partner)
        return response


    def getUserSettings(self):
        """
        get settings
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/smartLicensing/getUserSettings"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def syncLicenses(self, partner):
        """
        get all licenses for sa/va
        
        Parameters:
        partner:	Partner
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/smartLicensing/removeSaVaSelection"
        response = self.client.apiCall(HttpMethods.POST, endpoint, partner)
        return response


    def syncLicenses(self, partner):
        """
        get all licenses for sa/va
        
        Parameters:
        partner:	Partner
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/smartLicensing/syncLicenses"
        response = self.client.apiCall(HttpMethods.POST, endpoint, partner)
        return response


    def uploadAck(self, partner):
        """
        upload ack file  for sa/va
        
        Parameters:
        partner:	Partner
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/smartLicensing/uploadAck"
        response = self.client.apiCall(HttpMethods.POST, endpoint, partner)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class BFD(object):
    """
    Real-Time Monitoring - BFD API
    
    Implements GET POST DEL PUT methods for BFD endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getHistoryList(self, systemIp, color, deviceId):
        """
        Get BFD session history from device (Real Time)
        
        Parameters:
        systemIp	    (string):	System IP
		color	        (string):	Remote color
		deviceId	    (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/bfd/history?system-ip={systemIp}&color={color}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getLinkList(self, state):
        """
        Get list of BFD connections
        
        Parameters:
        state	 (string):	Device state
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/bfd/links?state={state}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSessions(self, systemIp, color, localColor, deviceId):
        """
        Get list of BFD sessions from vManage (Real Time)
        
        Parameters:
        systemIp	    (string):	System IP
		color	        (string):	Remote color
		local-color	    (string):	Source color
		deviceId	    (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/bfd/sessions?system-ip={systemIp}&color={color}&local-color={localColor}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSiteStateDetail(self):
        """
        Get detailed BFD site details
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/bfd/sites/detail"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSitesSummary(self, isCached, vpnId):
        """
        Get BFD site summary
        
        Parameters:
        isCached	 (boolean):	Flag for caching
		vpnId	 (array):	Filter VPN
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/bfd/sites/summary?isCached={isCached}&vpnId={vpnId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStateSummary(self, deviceId):
        """
        Get device BFD state summary
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/bfd/state/device?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStateSummaryTloc(self, deviceId):
        """
        Get device BFD state summary with tloc color
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/bfd/state/device/tloc?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatus(self):
        """
        Get device BFD status
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/bfd/status"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSummary(self, deviceId):
        """
        Get BFD summary from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/bfd/summary?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getStatusSummary(self, deviceId):
        """
        Get device BFD status summary
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/bfd/summary/device?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSyncSession(self, systemIp, color, localColor, deviceId):
        """
        Get list of BFD sessions from vManage synchronously
        
        Parameters:
        systemIp	    (string):	System IP
		color	        (string):	Remote color
		localColor	    (string):	Source color
		deviceId	    (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/bfd/synced/sessions?system-ip={systemIp}&color={color}&local-color={localColor}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getTLOCSummary(self, deviceId):
        """
        Get TLOC summary from device (Real Time)
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/bfd/tloc?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Device(object):
    """
    Certificate Management - Device API
    
    Implements GET POST DEL PUT methods for Device endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getCertDetails(self, parsecert):
        """
        Get cert details
        
        Parameters:
        parsecert:	parse cert
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/certificate/certdetails"
        response = self.client.apiCall(HttpMethods.POST, endpoint, parsecert)
        return response


    def getCSRViewRightMenus(self):
        """
        Get CSR detail view
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/certificate/csr/details"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDeviceViewRightMenus(self):
        """
        Get device detail view
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/certificate/device/details"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDevicesList(self):
        """
        Get vEdge list
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/certificate/device/list"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def forceSyncRootCert(self, singedcertificate):
        """
        Force sync root certificate
        NOTE: In a multitenant vManage system, this API is only available in the Provider and Provider-As-Tenant view.
        
        Parameters:
        singedcertificate:	Singed certificate
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/certificate/forcesync/rootCert"
        response = self.client.apiCall(HttpMethods.POST, endpoint, singedcertificate)
        return response


    def generateCSR(self, csrRequest):
        """
        Generate CSR
        NOTE: In a multitenant vManage system, this API is only available in the Provider and Provider-As-Tenant view.
        
        Parameters:
        csrRequest:	CSR request for device
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/certificate/generate/csr"
        response = self.client.apiCall(HttpMethods.POST, endpoint, csrRequest)
        return response


    def generateEntCSR(self, csrRequest):
        """
        Generate CSR
        NOTE: In a multitenant vManage system, this API is only available in the Provider and Provider-As-Tenant view.
        
        Parameters:
        csrRequest:	CSR request for device
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/certificate/generate/enterprise/csr/vedge"
        response = self.client.apiCall(HttpMethods.POST, endpoint, csrRequest)
        return response


    def generateVedgeEntCSR(self, csrRequest):
        """
        Generate CSR
        NOTE: In a multitenant vManage system, this API is only available in the Provider and Provider-As-Tenant view.
        
        Parameters:
        csrRequest:	CSR request for device
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/certificate/generate/wanedge/csr"
        response = self.client.apiCall(HttpMethods.POST, endpoint, csrRequest)
        return response


    def installCertificate(self, singedCert):
        """
        Install singed certificate
        NOTE: In a multitenant vManage system, this API is only available in the Provider and Provider-As-Tenant view.
        
        Parameters:
        singedCert:	Singed certificate
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/certificate/install/signedCert"
        response = self.client.apiCall(HttpMethods.POST, endpoint, singedCert)
        return response


    def updateJks(self, updatejks):
        """
        update JKS
        NOTE: In a multitenant vManage system, this API is only available in the Provider and Provider-As-Tenant view.
        
        Parameters:
        updatejks:	Update JKS
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/certificate/jks"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, updatejks)
        return response


    def getListStatus(self):
        """
        get certificate
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/certificate/list/status"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCertificateData(self):
        """
        Get certificate chain
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/certificate/record"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def resetRSA(self, csrRequest):
        """
        Register CSR
        NOTE: In a multitenant vManage system, this API is only available in the Provider and Provider-As-Tenant view.
        
        Parameters:
        csrRequest:	CSR request for vEdge
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/certificate/reset/rsa"
        response = self.client.apiCall(HttpMethods.POST, endpoint, csrRequest)
        return response


    def decommissionEnterpriseCSRForVedge(self, revokingcsrforhardwarevedge):
        """
        Revoking enterprise CSR for hardware vEdge
        NOTE: In a multitenant vManage system, this API is only available in the Provider and Provider-As-Tenant view.
        
        Parameters:
        revokingcsrforhardwarevedge:	Revoking CSR for hardware vEdge
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/certificate/revoke/enterprise/certificate"
        response = self.client.apiCall(HttpMethods.POST, endpoint, revokingcsrforhardwarevedge)
        return response


    def getRootCertChains(self, action):
        """
        Get root cert chain
        
        Parameters:
        action	 (string):	Action
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/certificate/rootcertchains?action={action}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def saveRootCertChain(self, rootChain):
        """
        Save root cert chain
        NOTE: In a multitenant vManage system, this API is only available in the Provider and Provider-As-Tenant view.
        
        Parameters:
        rootChain:	Save root cert chain
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/certificate/rootcertchains"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, rootChain)
        return response


    def getRootCertificate(self):
        """
        Get device root certificate detail view
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/certificate/rootcertificate"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def saveVEdgeList(self, deviceList):
        """
        Save vEdge device list
        
        Parameters:
        deviceList:	vEdge device list
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/certificate/save/vedge/list"
        response = self.client.apiCall(HttpMethods.POST, endpoint, deviceList)
        return response


    def getCertificateDetail(self):
        """
        Get certificate detail
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/certificate/stats/detail"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCertificateStats(self):
        """
        Get certificate expiration status
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/certificate/stats/summary"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def syncvBond(self):
        """
        sync vManage UUID to all vBond
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/certificate/syncvbond"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getcEdgeList(self):
        """
        Get cEdge list with tokengenerated list
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/certificate/tokengeneratedlist"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getInstalledCert(self):
        """
        Get Installed Certificate
        NOTE: In a multitenant vManage system, this API is only available in the Provider and Provider-As-Tenant view.
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/certificate/vedge"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getvEdgeCSR(self):
        """
        Get vEdge CSR Certificate
        NOTE: In a multitenant vManage system, this API is only available in the Provider and Provider-As-Tenant view.
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/certificate/vedge/csr"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getvEdgeList(self, model, state):
        """
        Get vEdge list
        
        Parameters:
        model	 (string):	Device model
		state	 (array):	Device state
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/certificate/vedge/list?model={model}&state={state}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def setvEdgeList(self, deviceList):
        """
        Save vEdge list
        
        Parameters:
        deviceList:	vEdge device list
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/certificate/vedge/list"
        response = self.client.apiCall(HttpMethods.POST, endpoint, deviceList)
        return response


    def getView(self):
        """
        Get certificate UI view
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/certificate/view"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getvSmartList(self):
        """
        Get vSmart list
        NOTE: In a multitenant vManage system, this API is only available in the Provider and Provider-As-Tenant view.
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/certificate/vsmart/list"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def setvSmartList(self):
        """
        Save vSmart list
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/certificate/vsmart/list"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def deleteConfig(self, uuid, replaceController, deviceId):
        """
        Invalidate device
        NOTE: In a multitenant vManage system, this API is only available in the Provider and Provider-As-Tenant view.
        
        Parameters:
        uuid	                (string):	Device uuid
		replaceController	    (boolean):	Replace a vSmart in Multi-tenant setup with a new vSmart
		deviceId	            (string):	uuid of new vSmart
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/certificate/{uuid}?replaceController={replaceController}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class WCM(object):
    """
    Partner - WCM Configs API
    
    Implements GET POST DEL PUT methods for WCM Configs endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def pushConfigs(self, config, nmsId):
        """
        Push device configs
        
        Parameters:
        config:	            Netconf configuration
		nmsId	 (string):	NMS Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/partner/wcm/netconf/{nmsId}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, config)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class CFM(object):
    """
    Real-Time Monitoring - CFM API
    
    Implements GET POST DEL PUT methods for CFM endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getMpDatabase(self, deviceId):
        """
        Get mp database from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/cfm/mp/database?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getMpLocalMep(self, domain, service, mepId, deviceId):
        """
        Get mp local mep from device
        
        Parameters:
        domain	 (string):	Domain Name
		service	 (string):	Service Name
		mepId	 (number):	MEP ID
		deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/cfm/mp/local/mep?domain={domain}&service={service}&mepId={mepId}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getMpLocalMip(self, level, port, svcInst, deviceId):
        """
        Get mp local mip from device
        
        Parameters:
        level	 (number):	Level
		port	 (string):	Port
		svcInst	 (number):	Service Instance
		deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/cfm/mp/local/mip?level={level}&port={port}&svcInst={svcInst}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getMpRemoteMep(self, domain, service, locMepId, remMepId, deviceId):
        """
        Get mp remote mep from device
        
        Parameters:
        domain	 (string):	Domain Name
		service	 (string):	Service Name
		locMepId	 (number):	Local MEP ID
		remMepId	 (number):	Remote MEP ID
		deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/cfm/mp/remotemep?domain={domain}&service={service}&locMepId={locMepId}&remMepId={remMepId}&deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class MultiCloud(object):
    """
    Configuration - Multi Cloud API
    
    Implements GET POST DEL PUT methods for MultiCloud endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def getAllCloudAccounts(self, cloudType, cgEnable):
        """
        Get All cloud accounts
        
        Parameters:
        cloudType	 (string):	Cloud type
		cgEnable	 (boolean):	Cloud gateway enabled flag
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/accounts?cloudType={cloudType}&cloudGatewayEnabled={cgEnable}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def validateAccountAdd(self, account):
        """
        Authenticate cloud account credentials
        
        Parameters:
        account:	Multicloud account info
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/accounts"
        response = self.client.apiCall(HttpMethods.POST, endpoint, account)
        return response


    def getEdgeAccounts(self, edgeType):
        """
        Get all Multicloud edge accounts
        
        Parameters:
        edgeType	 (string):	Edge type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/accounts/edge?edgeType={edgeType}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def validateEdgeAccountAdd(self, account):
        """
        Authenticate edge account credentials
        
        Parameters:
        account:	Multicloud edge account info
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/accounts/edge"
        response = self.client.apiCall(HttpMethods.POST, endpoint, account)
        return response


    def getEdgeAccountDetails(self, accountId):
        """
        Get edge account by account Id
        
        Parameters:
        accountId	 (string):	Edge Account Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/accounts/edge/{accountId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def updateEdgeAccount(self, account, accountId):
        """
        Update Multicloud edge account
        
        Parameters:
        account:	Multicloud edge account info
		accountId	 (string):	Multicloud Edge Account Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/accounts/edge/{accountId}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, account)
        return response


    def deleteEdgeAccount(self, accountId):
        """
        Delete edge account
        
        Parameters:
        accountId	 (string):	Edge Account Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/accounts/edge/{accountId}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response


    def validateEdgeAccountUpdateCred(self, account, accountId):
        """
        Update Multicloud edge account credential
        
        Parameters:
        account:	Multicloud edge account info
		accountId	 (string):	Multicloud Edge Account Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/accounts/edge/{accountId}/credentials"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, account)
        return response


    def getCloudAccountDetails(self, accountId):
        """
        Get cloud account by account Id
        
        Parameters:
        accountId	 (string):	Account Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/accounts/{accountId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def updateAccount(self, account, accountId):
        """
        Update multicloud account
        
        Parameters:
        account:	Multicloud account info
		accountId	 (string):	Account Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/accounts/{accountId}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, account)
        return response


    def deleteAccount(self, accountId):
        """
        Delete cloud account
        
        Parameters:
        accountId	 (string):	Account Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/accounts/{accountId}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response


    def validateAccountUpdateCred(self, account, accountId):
        """
        Update multicloud account credential
        
        Parameters:
        account:	Multicloud account info
		accountId	 (string):	Account Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/accounts/{accountId}/credentials"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, account)
        return response


    def auditDryRun(self, cloudType, cloudRegion):
        """
        Call an audit with dry run
        
        Parameters:
        cloudType	 (string):	Cloud type
		cloudRegion	 (string):	Region
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/audit?cloudType={cloudType}&cloudRegion={cloudRegion}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def audit(self, audit):
        """
        Call an audit
        
        Parameters:
        audit:	Audit
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/audit"
        response = self.client.apiCall(HttpMethods.POST, endpoint, audit)
        return response


    def getEdgeBillingAccounts(self, edgeType, edgeAccountId, region):
        """
        Get Edge Billing Accounts
        
        Parameters:
        edgeType	 (string):	Interconnect Provider
		edgeAccountId	 (string):	Interconnect Provider Account ID
		region	 (string):	Region
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/billingaccounts/edge/{edgeType}/{edgeAccountId}?region={region}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCgws(self, cloudType, accountId, region, cgName):
        """
        Get cloud gateways
        
        Parameters:
        cloudType	 (string):	Cloud type
		accountId	 (string):	Account Id
		region	 (string):	Region
		cgName	 (string):	Cloud gateway name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/cloudgateway?cloudType={cloudType}&accountId={accountId}&region={region}&cloudGatewayName={cgName}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createCgw(self, cg):
        """
        Create cloud gateway
        
        Parameters:
        cg:	Cloud gateway
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/cloudgateway"
        response = self.client.apiCall(HttpMethods.POST, endpoint, cg)
        return response


    def getAzureNetworkVirtualAppliances(self, cloudType, accoundId, region, rgName, rgSource, vhubName, vhubSource):
        """
        Discover Azure Virtual NVAs
        
        Parameters:
        cloudType	 (string):	Cloud type
		accoundId	 (string):	Account ID
		region	 (string):	Region
		rgName	 (string):	Resource Group Name
		rgSource	 (string):	Resource Group Source
		vhubName	 (string):	VHUB name
		vhubSource	 (string):	VHUB source
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/cloudgateway/nvas?cloudType={cloudType}&accoundId={accoundId}&region={region}&resourceGroupName={rgName}&resourceGroupSource={rgSource}&vhubName={vhubName}&vhubSource={vhubSource}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getAzureNvaSkuList(self):
        """
        Get Azure NVA SKUs
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/cloudgateway/nvasku"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCgwOrgResources(self, cgName):
        """
        Get cloud gateways
        
        Parameters:
        cgName	 (string):	Cloud gateway name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/cloudgateway/resource?cloudGatewayName={cgName}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getAzureResourceGroups(self, cloudType, accountId):
        """
        Discover Azure Resource Groups
        
        Parameters:
        cloudType	 (string):	Cloud type
		accountId	 (string):	Account ID
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/cloudgateway/resourceGroups?cloudType={cloudType}&accountId={accountId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getAzureVirtualHubs(self, cloudType, accoundId, region, rgName, rgSource, vwanName, vwanSource):
        """
        Discover Azure Virtual HUBs
        
        Parameters:
        cloudType	 (string):	Cloud type
		accoundId	 (string):	Account ID
		region	 (string):	Region
		rgName	 (string):	Resource Group Name
		rgSource	 (string):	Resource Group Source
		vwanName	 (string):	VWAN name
		vwanSource	 (string):	VWAN source
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/cloudgateway/vhubs?cloudType={cloudType}&accoundId={accoundId}&region={region}&resourceGroupName={rgName}&resourceGroupSource={rgSource}&vwanName={vwanName}&vwanSource={vwanSource}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getAzureVirtualWans(self, cloudType, accoundId, rgName, rgSource):
        """
        Discover Azure Virtual WANs
        
        Parameters:
        cloudType	 (string):	Cloud type
		accoundId	 (string):	Account ID
		rgName	 (string):	Resource Group Name
		rgSource	 (string):	Resource Group Source
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/cloudgateway/vwans?cloudType={cloudType}&accoundId={accoundId}&resourceGroupName={rgName}&resourceGroupSource={rgSource}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCgwDetails(self, cgName):
        """
        Get cloud gateway by name
        
        Parameters:
        cgName	 (string):	Cloud gateway name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/cloudgateway/{cgName}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def updateCgw(self, cloudgateway, cgName):
        """
        Update cloud gateway
        
        Parameters:
        cloudgateway:	Cloud gateway
		cgName	 (string):	Cloud gateway name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/cloudgateway/{cgName}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, cloudgateway)
        return response


    def deleteCgw(self, cgName):
        """
        Delete cloud gateway
        
        Parameters:
        cgName	 (string):	Cloud gateway name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/cloudgateway/{cgName}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response


    def getSites(self, cgName, systemIp, siteId, color, vpnTunnelStatus):
        """
        Get sites attached to CGW
        
        Parameters:
        cgName	 (string):	Cloud gateway name
		systemIp	 (string):	System IP
		siteId	 (string):	Site Id
		color	 (string):	Color
		vpnTunnelStatus	 (boolean):	Fetch vpnTunnelStatus
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/cloudgateway/{cgName}/site?systemIp={systemIp}&siteId={siteId}&color={color}&vpnTunnelStatus={vpnTunnelStatus}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def TunnelScaling(self, siteinformation, cgName):
        """
        Update tunnel scaling and accelerated vpn parameter for a branch endpoint
        
        Parameters:
        siteinformation:	Site information
		cgName	 (string):	Cloud gateway name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/cloudgateway/{cgName}/site"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, siteinformation)
        return response


    def attachSites(self, siteinformation, cgName):
        """
        Attach sites to cloud gateway
        
        Parameters:
        siteinformation:	Site information
		cgName	 (string):	Cloud gateway name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/cloudgateway/{cgName}/site"
        response = self.client.apiCall(HttpMethods.POST, endpoint, siteinformation)
        return response


    def detachSites(self, siteinformation, cgName):
        """
        Detach sites from cloud gateway
        
        Parameters:
        siteinformation:	Site information
		cgName	 (string):	Cloud gateway name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/cloudgateway/{cgName}/site"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint, siteinformation)
        return response


    def getCloudGateways(self, cloudType):
        """
        Get sites with connectivity to the cloud by cloud type
        
        Parameters:
        cloudType	 (string):	Cloud type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/cloudgateways/{cloudType}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCgwCustomSettingDetails(self, cgName):
        """
        Get cloud gateway custom setting by cloud gateway name
        
        Parameters:
        cgName	 (string):	Cloud gateway name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/cloudgatewaysetting/{cgName}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCgwTypes(self, cloudType):
        """
        Get cloud gateway types for specified cloudType
        
        Parameters:
        cloudType	 (string):	Cloud type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/cloudgatewaytype?cloudType={cloudType}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCloudConnectedSites(self, edgeType, edgeGatewayName):
        """
        Get sites with connectivity to the interconnect gateways by edge type
        
        Parameters:
        edgeType	 (string):	Edge type
		edgeGatewayName	 (string):	Interconnect Gateway Name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/connected-sites/edge/{edgeType}?edgeGatewayName={edgeGatewayName}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCloudConnectedSites(self, cloudType, cgName):
        """
        Get sites with connectivity to the cloud by cloud type
        
        Parameters:
        cloudType	 (string):	Cloud type
		cgName	 (string):	Cloud Gateway Name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/connected-sites/{cloudType}?cloudGatewayName={cgName}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getEdgeConnectivityDetails(self, edgeType, connectivityName, connectivityType, edgeGatewayName):
        """
        Get Interconnect Connectivity details
        
        Parameters:
        edgeType	 (string):	Edge type
		connectivityName	 (string):	Connectivity Name
		connectivityType	 (string):	Connectivity Type
		edgeGatewayName	 (string):	Interconnect Gateway name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/connectivity/edge?edgeType={edgeType}&connectivityName={connectivityName}&connectivityType={connectivityType}&edgeGatewayName={edgeGatewayName}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def updateEdgeConnectivity(self, edgeconnectivity):
        """
        Update Interconnect connectivity
        
        Parameters:
        edgeconnectivity:	Edge connectivity
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/connectivity/edge"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, edgeconnectivity)
        return response


    def createEdgeConnectivity(self, edgeconnectivity):
        """
        Create Interconnect connectivity
        
        Parameters:
        edgeconnectivity:	Edge connectivity
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/connectivity/edge"
        response = self.client.apiCall(HttpMethods.POST, endpoint, edgeconnectivity)
        return response


    def deleteEdgeConnectivity(self, connectionName):
        """
        Delete Interconnect connectivity
        
        Parameters:
        connectionName	 (string):	Edge connectivity name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/connectivity/edge/{connectionName}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response


    def getEdgeConnectivityDetailByName(self, connectivityName):
        """
        Get Interconnect Connectivity by name
        
        Parameters:
        connectivityName	 (string):	IC-GW connectivity name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/connectivity/edge/{connectivityName}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getConnectivityGateways(self, accountId, cloudType, connectivityType, connectivityGatewayName, region, network, state, refresh):
        """
        Get all Connectivity Gateways
        
        Parameters:
        accountId	 (string):	Account Id
		cloudType	 (string):	Cloud Type
		connectivityType	 (string):	Cloud Connectivity Type
		connectivityGatewayName	 (string):	Connectivity Gateway Name
		region	 (string):	Region
		network	 (string):	Network
		state	 (string):	State
		refresh	 (string):	Refresh
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/connectivitygateway?accountId={accountId}&cloudType={cloudType}&connectivityType={connectivityType}&connectivityGatewayName={connectivityGatewayName}&region={region}&network={network}&state={state}&refresh={refresh}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createConnectivityGateway(self, connectivitygateway):
        """
        Create Connectivity gateway
        
        Parameters:
        connectivitygateway:	Connectivity gateway
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/connectivitygateway"
        response = self.client.apiCall(HttpMethods.POST, endpoint, connectivitygateway)
        return response


    def cleanUpAllConnectivityGatewaysInLocalDB(self, deletionType):
        """
        Delete all Connectivity Gateways in local DB
        
        Parameters:
        deletionType	 (string):	Deletion Type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/connectivitygateway?deletionType={deletionType}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response


    def deleteConnectivityGateway(self, cloudProvider, connectivityGatewayName, connectivityType):
        """
        Delete Connectivity Gateway
        
        Parameters:
        cloudProvider	 (string):	Cloud Provider
		connectivityGatewayName	 (string):	Connectivity gateway name
		connectivityType	 (string):	Cloud Connectivity Type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/connectivitygateway/{cloudProvider}/{connectivityGatewayName}?connectivityType={connectivityType}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response


    def getConnectivityGatewayCreationOptions(self, accountId, cloudType, connectivityType, refresh):
        """
        Get connectivity gateway creation options
        
        Parameters:
        accountId	 (string):	Account Id
		cloudType	 (string):	Cloud Type
		connectivityType	 (string):	Cloud Connectivity Type
		refresh	 (string):	Refresh
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/connectivitygatewaycreationoptions?accountId={accountId}&cloudType={cloudType}&connectivityType={connectivityType}&refresh={refresh}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getDashboardEdgeInfo(self):
        """
        Get interconnect edge gateway dashboard info
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/dashboard/edge"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getWanDevices(self):
        """
        Get available WAN edge devices
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/device"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCloudDevices(self, edgeType, edgeGatewayName):
        """
        Get cloud devices by cloud type
        
        Parameters:
        edgeType	 (string):	Edge type
		edgeGatewayName	 (string):	Edge Gateway Name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/devices/edge/{edgeType}?edgeGatewayName={edgeGatewayName}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCloudDevices(self, cloudType, cgName):
        """
        Get cloud devices by cloud type
        
        Parameters:
        cloudType	 (string):	Cloud type
		cgName	 (string):	Cloud Gateway Name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/devices/{cloudType}?cloudGatewayName={cgName}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getEdgeWanDevices(self, edgeType):
        """
        Get available WAN edge devices
        
        Parameters:
        edgeType	 (string):	Edge Type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/edge/{edgeType}/device"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getIcgws(self, edgeType, accountId, region, regionId, resourceState, edgeGatewayName):
        """
        Get Interconnect Gateways
        
        Parameters:
        edgeType	 (string):	Edge type
		accountId	 (string):	Account Id
		region	 (string):	Region
		regionId	 (string):	Region Id
		resourceState	 (string):	Resource State
		edgeGatewayName	 (string):	Edge gateway name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/gateway/edge?edgeType={edgeType}&accountId={accountId}&region={region}&regionId={regionId}&resourceState={resourceState}&edgeGatewayName={edgeGatewayName}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createIcgw(self, interconnectgateway):
        """
        Create Interconnect Gateway
        
        Parameters:
        interconnectgateway:	Interconnect Gateway
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/gateway/edge"
        response = self.client.apiCall(HttpMethods.POST, endpoint, interconnectgateway)
        return response


    def getIcgwCustomSettingDetails(self, edgeGatewayName):
        """
        Get Interconnect Gateway custom setting by Interconnect Gateway name
        
        Parameters:
        edgeGatewayName	 (string):	Edge gateway name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/gateway/edge/setting/{edgeGatewayName}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getIcgwTypes(self, edgeType):
        """
        Get Interconnect Gateway type for specified Edge Provider
        
        Parameters:
        edgeType	 (string):	Edge type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/gateway/edge/types?edgeType={edgeType}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getIcgwDetails(self, edgeGatewayName):
        """
        Get Interconnect Gateway by name
        
        Parameters:
        edgeGatewayName	 (string):	Edge gateway name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/gateway/edge/{edgeGatewayName}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def updateIcgw(self, gatewayInfo, edgeGatewayName):
        """
        Update Interconnect Gateway
        
        Parameters:
        gatewayInfo:	Description
		edgeGatewayName	 (string):	Edge gateway name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/gateway/edge/{edgeGatewayName}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, gatewayInfo)
        return response


    def deleteIcgw(self, edgeGatewayName):
        """
        Delete Interconnect Gateway
        
        Parameters:
        edgeGatewayName	 (string):	Edge gateway name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/gateway/edge/{edgeGatewayName}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response


    def getEdgeGateways(self, edgeType):
        """
        Get sites with connectivity to the interconnect gateways by edge type
        
        Parameters:
        edgeType	 (string):	Edge type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/gateways/edge/{edgeType}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getHostVpcs(self, cloudType, accountIds, region, untagged):
        """
        Get tagged, untagged, or all Host VPCs
        
        Parameters:
        cloudType	 (string):	Cloud type
		accountIds	 (string):	Account Id
		region	 (string):	Region
		untagged	 (string):	Untagged flag
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/hostvpc?cloudType={cloudType}&accountIds={accountIds}&region={region}&untagged={untagged}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getVpcTags(self, cloudType, region, tagName):
        """
        Get vpc tags
        
        Parameters:
        cloudType	 (string):	Cloud type
		region	 (string):	Region
		tagName	 (string):	Tag name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/hostvpc/tags?cloudType={cloudType}&region={region}&tagName={tagName}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def editTag(self, vpctag):
        """
        Edit VPCs for a tag
        
        Parameters:
        vpctag:	VPC tag
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/hostvpc/tags"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, vpctag)
        return response


    def hostvpcTagging(self, vpctag):
        """
        Tag a VPC
        
        Parameters:
        vpctag:	VPC tag
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/hostvpc/tags"
        response = self.client.apiCall(HttpMethods.POST, endpoint, vpctag)
        return response


    def unTag(self, tagName):
        """
        Delete a tag
        
        Parameters:
        tagName	 (string):	Tag name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/hostvpc/tags/{tagName}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response


    def getSupportedEdgeImageNames(self, edgeType):
        """
        Get Edge provider supported images
        
        Parameters:
        edgeType	 (string):	Edge type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/imagename/edge?edgeType={edgeType}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSupportedInstanceSize(self, cloudType, accountId, cloudRegion):
        """
        Get Transit VPC supported size
        
        Parameters:
        Parameter Description
		Parameter Description
		Parameter Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/instancesize?cloudType={cloudType}&accountId={accountId}&cloudRegion={cloudRegion}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSupportedEdgeInstanceSize(self, edgeType):
        """
        Get Edge provider supported size
        
        Parameters:
        edgeType	 (string):	Edge type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/instancesize/edge?edgeType={edgeType}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getWanInterfaceColors(self):
        """
        Get WAN interface colors
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/interfacecolor"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getEdgeLocationsInfo(self, edgeType, accountId, region):
        """
        Get Edge Locations
        
        Parameters:
        edgeType	 (string):	Edge Type
		accountId	 (string):	Edge Account Id
		region	 (string):	Region
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/locations/edge/{edgeType}?accountId={accountId}&region={region}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def deleteEdgeAccount(self, edgeType):
        """
        Delete edge account
        
        Parameters:
        edgeType	 (string):	Edge Type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/locations/edge/{edgeType}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response


    def updateEdgeLocationsInfo(self, edgeType, accountId):
        """
        Update Edge Locations
        
        Parameters:
        edgeType	 (string):	Edge Type
		accountId	 (string):	Edge Account Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/locations/edge/{edgeType}/accountId/{accountId}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint)
        return response


    def getMappingMatrix(self, cloudType):
        """
        Get default mapping values
        
        Parameters:
        cloudType	 (string):	Cloud type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/map?cloudType={cloudType}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def processMapping(self, vpcmapping):
        """
        Process intent of connecting VPNs with VPCs through cloud gateway
        
        Parameters:
        vpcmapping:	VPC mapping
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/map"
        response = self.client.apiCall(HttpMethods.POST, endpoint, vpcmapping)
        return response


    def getDefaultMappingValues(self, cloudType):
        """
        Get default mapping values
        
        Parameters:
        cloudType	 (string):	Cloud type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/map/defaults?cloudType={cloudType}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getMappingStatus(self, cloudType, region):
        """
        Get mapping status
        
        Parameters:
        cloudType	 (string):	Cloud type
		region	 (string):	Region
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/map/status?cloudType={cloudType}&region={region}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getMappingSummary(self, vpnTunnelStatus, cloudType):
        """
        Get mapping summary
        
        Parameters:
        vpnTunnelStatus	 (boolean):	VPN tunnel status
		cloudType	 (string):	Cloud type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/map/summary?vpnTunnelStatus={vpnTunnelStatus}&cloudType={cloudType}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getMappingTags(self, cloudType):
        """
        Get default mapping values
        
        Parameters:
        cloudType	 (string):	Cloud type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/map/tags?cloudType={cloudType}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getEdgeMappingTags(self, cloudType, accountId):
        """
        Get default Interconnect mapping tag values
        
        Parameters:
        cloudType	 (string):	Cloud type
		accountId	 (string):	Cloud Account Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/map/tags/edge?cloudType={cloudType}&accountId={accountId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getMappingVpns(self):
        """
        Get default mapping values
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/map/vpns"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCgwAssociatedMappings(self, cloudType, cgName, siteUuid):
        """
        Get associated mappings to the CGW
        
        Parameters:
        cloudType	 (string):	Cloud type
		cgName	 (string):	Cloud Gateway Name
		siteUuid	 (string):	Site Device UUID
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/mapping/{cloudType}?cloudGatewayName={cgName}&siteUuid={siteUuid}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getPartnerPorts(self, edgeType, accountId, cloudType, connectType, vxcPermitted, authorizationKey, refresh):
        """
        Get partner ports
        
        Parameters:
        edgeType	 (string):	Edge type
		accountId	 (string):	Edge Account Id
		cloudType	 (string):	Cloud Type
		connectType	 (string):	Connect Type filter
		vxcPermitted	 (string):	VXC Permitted on the port
		authorizationKey	 (string):	authorization Key
		refresh	 (string):	Refresh
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/partnerports/edge?edgeType={edgeType}&accountId={accountId}&cloudType={cloudType}&connectType={connectType}&vxcPermitted={vxcPermitted}&authorizationKey={authorizationKey}&refresh={refresh}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getPortSpeed(self, edgeType, edgeAccountId, connectivityType, cloudType, cloudAccountId, connectType, connectSubType, connectivityGateway, partnerPort):
        """
        Get supported port speed
        
        Parameters:
        edgeType	 (string):	Interconnect Provider
		edgeAccountId	 (string):	Interconnect Provider Account ID
		connectivityType	 (string):	Interconnect Connectivity Type
		cloudType	 (string):	Cloud Service Provider
		cloudAccountId	 (string):	Cloud Service Provider Account ID
		connectType	 (string):	Connection Type filter
		connectSubType	 (string):	Connection Sub-Type filter
		connectivityGateway	 (string):	Connectivity Gateway
		partnerPort	 (string):	partnerPort
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/portSpeed/edge/{edgeType}/{edgeAccountId}/{connectivityType}?cloudType={cloudType}&cloudAccountId={cloudAccountId}&connectType={connectType}&connectSubType={connectSubType}&connectivityGateway={connectivityGateway}&partnerPort={partnerPort}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCloudRegions(self, cloudType):
        """
        Get cloud regions
        
        Parameters:
        cloudType	 (string):	Cloud type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/regions?cloudType={cloudType}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getEdgeGlobalSettings(self, edgeType):
        """
        Get edge global settings
        
        Parameters:
        edgeType	 (string):	Edge type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/settings/edge/global?edgeType={edgeType}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def updateEdgeGlobalSettings(self, globalsetting):
        """
        Update edge global settings for Edge provider
        
        Parameters:
        globalsetting:	Global setting
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/settings/edge/global"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, globalsetting)
        return response


    def addEdgeGlobalSettings(self, globalsetting):
        """
        Add global settings for Edge provider
        
        Parameters:
        globalsetting:	Global setting
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/settings/edge/global"
        response = self.client.apiCall(HttpMethods.POST, endpoint, globalsetting)
        return response


    def getGlobalSettings(self, cloudType):
        """
        Get global settings
        
        Parameters:
        cloudType	 (string):	Cloud type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/settings/global?cloudType={cloudType}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def updateGlobalSettings(self, globalsetting):
        """
        Update ip in resource pool
        
        Parameters:
        globalsetting:	Global setting
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/settings/global"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, globalsetting)
        return response


    def addGlobalSettings(self, globalsetting):
        """
        Acquire ip from resource pool
        
        Parameters:
        globalsetting:	Global setting
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/settings/global"
        response = self.client.apiCall(HttpMethods.POST, endpoint, globalsetting)
        return response


    def getSites(self, color, attached):
        """
        Get available sites
        
        Parameters:
        color	 (string):	Color
		attached	 (boolean):	Is endpoint attached
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/site?color={color}&attached={attached}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getSshKeyList(self, cloudType, accountId, cloudRegion):
        """
        Get SSH keys
        
        Parameters:
        cloudType	 (string):	Cloud type
		accountId	 (string):	Account Id
		cloudRegion	 (string):	Region
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/sshkeys?cloudType={cloudType}&accountId={accountId}&cloudRegion={cloudRegion}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getPostAggregationDataByQuery(self, statsquerystring):
        """
        Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
        
        Parameters:
        statsquerystring:	Stats query string
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/statistics/interface/aggregation"
        response = self.client.apiCall(HttpMethods.POST, endpoint, statsquerystring)
        return response


    def getSupportedSoftwareImageList(self, cloudType, accountId, cloudRegion):
        """
        Get software image list
        
        Parameters:
        cloudType	 (string):	Cloud type
		accountId	 (string):	Account Id
		cloudRegion	 (string):	Region
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/swimages?cloudType={cloudType}&accountId={accountId}&cloudRegion={cloudRegion}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def telemetry(self, telemetry):
        """
        reports telemetry data
        
        Parameters:
        telemetry:	telemetry
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/telemetry"
        response = self.client.apiCall(HttpMethods.POST, endpoint, telemetry)
        return response


    def getTunnelNames(self, cloudType, cgName):
        """
        Get tunnel names
        
        Parameters:
        cloudType	 (string):	Cloud type
		cgName	 (string):	Cloud gateway name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/tunnels/{cloudType}?cloudGatewayName={cgName}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCloudTypes(self):
        """
        Get cloud types
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/types"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getEdgeTypes(self):
        """
        Get edge types
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/types/edge"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getVHubs(self, cloudType, accountId, resourceGroup, vWanName, vNetTags):
        """
        Get Virtual Hubs
        
        Parameters:
        cloudType	 (string):	Cloud Type
		accountId	 (string):	Account Id
		resourceGroup	 (string):	Resource Group
		vWanName	 (string):	VWan Name
		vNetTags	 (string):	VNet Tags
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/vhubs?cloudType={cloudType}&accountId={accountId}&resourceGroup={resourceGroup}&vWanName={vWanName}&vNetTags={vNetTags}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createVirtualWan(self, virtualwan):
        """
        Create Virtual WAN
        
        Parameters:
        virtualwan:	Virtual WAN
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/vwan"
        response = self.client.apiCall(HttpMethods.POST, endpoint, virtualwan)
        return response


    def deleteVirtualWan(self, cloudProvider, vWanName):
        """
        Delete Virtual Wan
        
        Parameters:
        cloudProvider	 (string):	Cloud Provider
		vWanName	 (string):	Virtual Wan name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/vwan/{cloudProvider}/{vWanName}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response


    def getVWans(self, accountId, cloudType, resourceGroup, refresh):
        """
        Get Virtual Wans
        
        Parameters:
        accountId	 (string):	Account Id
		cloudType	 (string):	Cloud Type
		resourceGroup	 (string):	Resource Group
		refresh	 (string):	Refresh
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/vwans?accountId={accountId}&cloudType={cloudType}&resourceGroup={resourceGroup}&refresh={refresh}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getEdgeWidget(self, edgeType):
        """
        Get Interconnect Edge widget by edge type
        
        Parameters:
        edgeType	 (string):	Edge type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/widget/edge/{edgeType}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getCloudWidget(self, cloudType):
        """
        Get cloud widget by cloud type
        
        Parameters:
        cloudType	 (string):	Cloud type
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/multicloud/widget/{cloudType}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Migration(object):
    """
    Tenant Migration API
    
    Implements GET POST DEL PUT methods for Tenant Migration endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def downloadData(self, path):
        """
        Download tenant data
        
        Parameters:
        path	 (string):	File path
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/tenantmigration/download/{path}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def exportData(self, bodyParameter):
        """
        Export tenant data
        
        Parameters:
        bodyParameter:	Description
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/tenantmigration/export"
        response = self.client.apiCall(HttpMethods.POST, endpoint, bodyParameter)
        return response


    def importData(self):
        """
        Import tenant data
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/tenantmigration/import"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def getToken(self, migrationId):
        """
        Get migration token
        
        Parameters:
        migrationId	 (string):	Migration Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/tenantmigration/migrationToken?migrationId={migrationId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def reTrigger(self):
        """
        Re-trigger network migration
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/tenantmigration/networkMigration"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def migrate(self, networkMigration):
        """
        Migrate network
        
        Parameters:
        networkMigration:	Network migration
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/tenantmigration/networkMigration"
        response = self.client.apiCall(HttpMethods.POST, endpoint, networkMigration)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Status(object):
    """
    Monitoring - Status API
    
    Implements GET POST DEL PUT methods for Status endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def getDisabledDeviceList(self, indexName):
        """
        Get list of disabled devices for a statistics index
        
        Parameters:
        indexName	 (string):	Index name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/settings/disable/devicelist/{indexName}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def updateDeviceList(self, disableddevice, indexName):
        """
        Update list of disabled devices for a statistics index
        
        Parameters:
        disableddevice:	Disabled device
		indexName	 (string):	Index name
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/settings/disable/devicelist/{indexName}"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, disableddevice)
        return response


    def getSettings(self):
        """
        Get statistics settings
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/settings/status"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def updateSettings(self, statssetting):
        """
        Update statistics settings
        
        Parameters:
        statssetting:	Stats setting
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/settings/status"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, statssetting)
        return response


    def getEnabledIndex(self, deviceId):
        """
        Get list of enabled device for statistics index
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/statistics/settings/status/device?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Firmware(object):
    """
    Configuration - Device Firmware Update API
    
    Implements GET POST DEL PUT methods for DeviceFirmwareUpdate endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def get(self):
        """
        Get list of firmware images in the repository
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/firmware"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def process(self):
        """
        Upload firmware image package
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/firmware"
        response = self.client.apiCall(HttpMethods.POST, endpoint)
        return response


    def activate(self, fwInfo):
        """
        Activate firmware on device
        
        Parameters:
        fwInfo:    Firmware Info
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/firmware/activate"
        response = self.client.apiCall(HttpMethods.POST, endpoint, fwInfo)
        return response


    def getDevicesFWUpgrade(self):
        """
        Get list of devices that support firmware upgrade
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/firmware/devices"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def install(self, fwInfo):
        """
        Install firmware on device
        
        Parameters:
        fwInfo:    Firmware Info
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/firmware/install"
        response = self.client.apiCall(HttpMethods.POST, endpoint, fwInfo)
        return response


    def remove(self, fwInfo):
        """
        Remove firmware on device
        
        Parameters:
        fwInfo:    Firmware Info
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/firmware/remove"
        response = self.client.apiCall(HttpMethods.POST, endpoint, fwInfo)
        return response


    def getDetails(self, versionId):
        """
        Get firmware image details for a given version
        
        Parameters:
        versionId	 (string):	Firmware image version
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/firmware/{versionId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def delete(self, versionId):
        """
        Delete firmware image package
        
        Parameters:
        versionId	 (string):	Firmware image version
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/action/firmware/{versionId}"
        response = self.client.apiCall(HttpMethods.DELETE, endpoint)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Proxy(object):
    """
    Configuration - Device SSL Proxy Certificate Management API
    
    Implements GET POST DEL PUT methods for DeviceSSLProxyCertificateManagement endpoints

    """

    def __init__(self, session, host, port):
        self.host = host
        self.port = port
        self.client = HttpMethods.HttpClient(session=session)
    
    
    def getSelfSignedCert(self):
        """
        get self signed certificate
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/certificate/vmanage/selfsignedcert"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getProxyCertOfEdge(self, deviceId):
        """
        Get edge proxy certificate
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/sslproxy/certificate?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def updateCert(self, cert):
        """
        Upload device certificate
        
        Parameters:
        cert:	Upload device certificate
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/sslproxy/certificate"
        response = self.client.apiCall(HttpMethods.PUT, endpoint, cert)
        return response


    def addWANEdge(self, certstate, deviceId):
        """
        Add SSL proxy wan edge
        
        Parameters:
        certstate:	Cert state
		deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/sslproxy/certificate/wanedge/{deviceId}"
        response = self.client.apiCall(HttpMethods.POST, endpoint, certstate)
        return response


    def uploadCerts(self, certFile):
        """
        Upload device certificates
        
        Parameters:
        certFile:	Certificate file
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/sslproxy/certificates"
        response = self.client.apiCall(HttpMethods.POST, endpoint, certFile)
        return response


    def getSslProxyCSR(self, deviceId):
        """
        Get SSL proxy CSR
        
        Parameters:
        deviceId	 (string):	Device Id
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/sslproxy/csr?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getAllDeviceCerts(self, devicelist):
        """
        Get certificate for all cEdges
        
        Parameters:
        devicelist:	Device list
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/sslproxy/devicecertificates"
        response = self.client.apiCall(HttpMethods.POST, endpoint, devicelist)
        return response


    def getAllDeviceCSR(self, devicelist):
        """
        Get CSR for all cEdges
        
        Parameters:
        devicelist:	Device list
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/sslproxy/devicecsr"
        response = self.client.apiCall(HttpMethods.POST, endpoint, devicelist)
        return response


    def generateSslProxyCSR(self, csrRequest):
        """
        CSR request SSL proxy for edge
        
        Parameters:
        csrRequest:	CSR request for edge
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/sslproxy/generate/csr/sslproxy"
        response = self.client.apiCall(HttpMethods.POST, endpoint, csrRequest)
        return response


    def generateSSLProxyCSR(self, csrRequest):
        """
        Generate CSR
        
        Parameters:
        csrRequest:	CSR request
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/sslproxy/generate/vmanage/csr"
        response = self.client.apiCall(HttpMethods.POST, endpoint, csrRequest)
        return response


    def getSslProxyList(self):
        """
        Get SSL proxy certificate list
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/sslproxy/list"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def renewCert(self, certRequest):
        """
        Renew device certificate
        
        Parameters:
        certRequest:	Renew device certificate request
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/sslproxy/renew"
        response = self.client.apiCall(HttpMethods.POST, endpoint, certRequest)
        return response


    def revokeCert(self, certRequest):
        """
        Revoke device certificate
        
        Parameters:
        certRequest:	Revoke device certificate request
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/sslproxy/revoke"
        response = self.client.apiCall(HttpMethods.POST, endpoint, certRequest)
        return response


    def revokeRenewCert(self, certRequest):
        """
        Revoke and renew device certificate
        
        Parameters:
        certRequest:	Revoke device certificate request
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/sslproxy/revokerenew"
        response = self.client.apiCall(HttpMethods.POST, endpoint, certRequest)
        return response


    def getCertState(self):
        """
        Get certificate state
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/sslproxy/settings/certificate"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getEntCert(self):
        """
        Get enterprise certificate
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/sslproxy/settings/enterprise/certificate"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def setEntCert(self, certRequest):
        """
        Configure enterprise certificate
        
        Parameters:
        certRequest:	Config enterprise certificate request
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/sslproxy/settings/enterprise/certificate"
        response = self.client.apiCall(HttpMethods.POST, endpoint, certRequest)
        return response


    def getVManageEntRootCert(self):
        """
        Get vManage enterprise root certificate
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/sslproxy/settings/enterprise/rootca"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def setEntRootCaCert(self, certRequest):
        """
        Set vManage enterprise root certificate
        
        Parameters:
        setenterpriserootcarequest:	Set enterprise root CA request
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/sslproxy/settings/enterprise/rootca"
        response = self.client.apiCall(HttpMethods.POST, endpoint, certRequest)
        return response


    def getvManageCert(self):
        """
        Get vManage intermediate certificate
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/sslproxy/settings/vmanage/certificate"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def setvManageintermediateCert(self, certRequest):
        """
        Set vManage root certificate
        
        Parameters:
        certRequest:	Set vManage intermediate CA request
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/sslproxy/settings/vmanage/certificate"
        response = self.client.apiCall(HttpMethods.POST, endpoint, certRequest)
        return response


    def getvManageCSR(self):
        """
        Get vManage CSR
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/sslproxy/settings/vmanage/csr"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def getvManageRootCA(self):
        """
        Get vManage root certificate
        
        Parameters:
                
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/sslproxy/settings/vmanage/rootca"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def setvManageRootCA(self, certRequest):
        """
        Set vManage root certificate
        
        Parameters:
        certRequest:	Set vManage root CA request
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/sslproxy/settings/vmanage/rootca"
        response = self.client.apiCall(HttpMethods.POST, endpoint, certRequest)
        return response





from py_viptela.query_builder import Builder
from py_viptela import HttpMethods

class Multicast(object):
    """
    Real-Time Monitoring - Multicast API
    
    Implements GET POST DEL PUT methods for Multicast endpoints

    """

    def __init__(self, session, host, port):
        self.client = HttpMethods.HttpClient(session=session)
        self.host = host
        self.port = port
    
    
    def createReplicatorList(self, deviceId):
        """
        Get replicator list from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/multicast/replicator?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createRpfList(self, deviceId):
        """
        Get RPF list from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/multicast/rpf?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createTopologyList(self, deviceId):
        """
        Get topology list from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/multicast/topology?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


    def createPimTunnelList(self, deviceId):
        """
        Get PIM tunnel from device
        
        Parameters:
        deviceId	 (string):	Device IP
        
        Returns
        response    (dict)
        
        
        """
        
        endpoint = f"https://{self.host}:{self.port}/dataservice/device/multicast/tunnel?deviceId={deviceId}"
        response = self.client.apiCall(HttpMethods.GET, endpoint)
        return response


